pub trait KeyIvInit:
KeySizeUser
+ IvSizeUser
+ Sized {
// Required method
fn new(key: &Key<Self>, iv: &Iv<Self>) -> Self;
// Provided method
fn new_from_slices(key: &[u8], iv: &[u8]) -> Result<Self, InvalidLength> { ... }
}Expand description
Types which can be initialized from a key and initialization vector (nonce).
Required Methods
Provided Methods
Sourcefn new_from_slices(key: &[u8], iv: &[u8]) -> Result<Self, InvalidLength>
fn new_from_slices(key: &[u8], iv: &[u8]) -> Result<Self, InvalidLength>
Create new value from variable length key and nonce.
Errors
Returns InvalidLength in the event that key and/or iv are not the expected length.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".